@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '5.21.3';
+our $VERSION = 'v5.23.1';
 
 URPM->bootstrap($VERSION);
 
@@ -967,12 +967,6 @@ Destroys macros.
 
 =over
 
-=item specbuild($mode, $specfile, [ defines => [ '_topdir /tmp/XYZ', ... ] ])
-
-Build a package from the spec file pointed by the file path. It's possible to define extra macros.
-B<$mode> is one of 'ba', 'bb' or 'bs'.
-B<defines> enables to define some value (like rpmbuild --define '_topdir /tmp/').
-
 =item setVerbosity($level)
 
 Sets rpm verbosity level. $level is an integer between 2 (RPMMESS_CRIT) and 7
@@ -1050,6 +1044,8 @@ B<transaction_state>: $state object
 
 The L<URPM::Resolve> implements the resolving bits.
 
+The L<URPM::Signature> implements the pubkey bits.
+
 The L<urpm> package is a higher level module used by the urpmi command line tool,
 the rpmdrake GUI and the drakx installer.
 
